@@ -15,6 +15,8 @@
 //! }
 //! ```
 
+use std::path::Path;
+
 use lief_ffi as ffi;
 
 use crate::common::into_optional;
@@ -24,6 +26,7 @@ pub mod compilation_unit;
 pub mod public_symbol;
 pub mod function;
 pub mod types;
+pub mod build_metadata;
 
 #[doc(inline)]
 pub use debug_info::DebugInfo;
@@ -40,7 +43,15 @@ pub use function::Function;
 #[doc(inline)]
 pub use types::Type;
 
-/// Load a PDB from its file path
-pub fn load(path: &str) -> Option<DebugInfo> {
-    into_optional(ffi::PDB_DebugInfo::from_file(path))
+#[doc(inline)]
+pub use build_metadata::BuildMetadata;
+
+/// Load a PDB from its filepath
+pub fn load<P: AsRef<Path>>(path: P) -> Option<DebugInfo<'static>> {
+    into_optional(ffi::PDB_DebugInfo::from_file(path.as_ref().to_str().unwrap()))
+}
+
+/// Check if the given file is a `PDB`
+pub fn is_pdb<P: AsRef<Path>>(path: P) -> bool {
+    ffi::PDB_Utils::is_pdb(path.as_ref().to_str().unwrap())
 }
