@@ -1,5 +1,5 @@
-/* Copyright 2017 - 2024 R. Thomas
- * Copyright 2017 - 2024 Quarkslab
+/* Copyright 2017 - 2025 R. Thomas
+ * Copyright 2017 - 2025 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -86,6 +86,8 @@ class LIEF_API Method : public Object {
   /// ACCESS_FLAGS as an std::set
   access_flags_list_t access_flags() const;
 
+  // CodeInfo to get additional data about a method i.e. argument count
+  const CodeInfo& code_info() const;
 
   LIEF_API friend std::ostream& operator<<(std::ostream& os, const Method& mtd);
 
