@@ -1,5 +1,5 @@
-/* Copyright 2017 - 2024 R. Thomas
- * Copyright 2017 - 2024 Quarkslab
+/* Copyright 2017 - 2025 R. Thomas
+ * Copyright 2017 - 2025 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -21,4 +21,7 @@
 #include <LIEF/PE/debug/PogoEntry.hpp>
 #include <LIEF/PE/debug/Repro.hpp>
 #include <LIEF/PE/debug/CodeViewPDB.hpp>
+#include <LIEF/PE/debug/VCFeature.hpp>
+#include <LIEF/PE/debug/ExDllCharacteristics.hpp>
+#include <LIEF/PE/debug/FPO.hpp>
 #endif
