@@ -1,5 +1,5 @@
-/* Copyright 2017 - 2024 R. Thomas
- * Copyright 2017 - 2024 Quarkslab
+/* Copyright 2017 - 2025 R. Thomas
+ * Copyright 2017 - 2025 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -61,6 +61,10 @@ Relocation::TYPE Relocation::type_from(uint32_t value, ARCH arch) {
       return TYPE(value | R_RISCV);
     case ARCH::BPF:
       return TYPE(value | R_BPF);
+    case ARCH::SH:
+      return TYPE(value | R_SH4);
+    case ARCH::S390:
+      return TYPE(value | R_SYSZ);
     default:
       {
         if (ERR.insert(arch).second) {
@@ -144,6 +148,12 @@ Relocation::Relocation(uint64_t address, TYPE type, ENCODING encoding) :
     else if (ID == Relocation::R_BPF) {
       architecture_ = ARCH::BPF;
     }
+    else if (ID == Relocation::R_SH4) {
+      architecture_ = ARCH::SH;
+    }
+    else if (ID == Relocation::R_SYSZ) {
+      architecture_ = ARCH::S390;
+    }
   }
 }
 
@@ -389,7 +399,6 @@ result<uint64_t> Relocation::resolve(uint64_t base_address) const {
       case TYPE::LARCH_SUB64:
         return (Q() - (S + A));
     /* } */
-
     default:
       break;
   }
@@ -415,6 +424,12 @@ std::ostream& operator<<(std::ostream& os, const Relocation& entry) {
       symbol_name = symbol->name();
     }
   }
+  if (entry.size() == uint64_t(-1)) {
+    os << fmt::format("0x{:06x} {} 0x{:04x} 0x{:02x} {}",
+                      entry.address(), to_string(entry.type()),
+                      entry.addend(), entry.info(), symbol_name);
+    return os;
+  }
 
   os << fmt::format("0x{:06x} {} ({}) 0x{:04x} 0x{:02x} {}",
                     entry.address(), to_string(entry.type()),
