@@ -1,5 +1,5 @@
-/* Copyright 2017 - 2024 R. Thomas
- * Copyright 2017 - 2024 Quarkslab
+/* Copyright 2017 - 2025 R. Thomas
+ * Copyright 2017 - 2025 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,13 +14,19 @@
  * limitations under the License.
  */
 #include "LIEF/Visitor.hpp"
+#include "LIEF/BinaryStream/BinaryStream.hpp"
+
 
 #include "PE/Structures.hpp"
+#include "LIEF/PE/Binary.hpp"
+#include "LIEF/PE/Parser.hpp"
 #include "LIEF/PE/Relocation.hpp"
 #include "LIEF/PE/RelocationEntry.hpp"
 
 #include <spdlog/fmt/fmt.h>
 
+#include "logging.hpp"
+
 namespace LIEF {
 namespace PE {
 
@@ -82,15 +88,61 @@ void Relocation::accept(LIEF::Visitor& visitor) const {
 }
 
 std::ostream& operator<<(std::ostream& os, const Relocation& relocation) {
-  os << fmt::format("0x{:06x} 0x{:06x}\n", relocation.virtual_address(),
-                    relocation.block_size());
-
+  using namespace fmt;
+  os << format("Page RVA: 0x{:08x} (SizeOfBlock: {} bytes)\n",
+               relocation.virtual_address(), relocation.block_size());
   for (const RelocationEntry& entry : relocation.entries()) {
-    os << "    - " << entry << '\n';
+    os << "  " << entry << '\n';
   }
 
   return os;
 }
 
+Relocation::relocations_t Relocation::parse(Parser& ctx, BinaryStream& stream) {
+  relocations_t relocs;
+  const Header::MACHINE_TYPES arch = ctx.bin().header().machine();
+  while (stream) {
+    auto PageRVA = stream.read<uint32_t>();
+    if (!PageRVA) {
+      LIEF_DEBUG("Error: {}:{}", __FUNCTION__, __LINE__);
+      return relocs;
+    }
+
+    auto BlockSize = stream.read<uint32_t>();
+    if (!BlockSize) {
+      LIEF_DEBUG("Error: {}:{}", __FUNCTION__, __LINE__);
+      return relocs;
+    }
+
+    auto relocation = std::make_unique<Relocation>(*PageRVA, *BlockSize);
+    // Must be at least sizeof(PageRVA + BlockSize)
+    if (*BlockSize < 2 * 4) {
+      relocs.push_back(std::move(relocation));
+      return relocs;
+    }
+
+    const size_t nb_entries = (*BlockSize - 8) / sizeof(uint16_t);
+    {
+      ScopedStream block_strm(stream);
+      for (size_t i = 0; i < nb_entries; ++i) {
+        auto data = block_strm->read<uint16_t>();
+        if (!data) {
+          LIEF_DEBUG("Error: {}:{} (entry: {})", __FUNCTION__, __LINE__, i);
+          break;
+        }
+
+        uint16_t pos = RelocationEntry::get_position(*data);
+        RelocationEntry::BASE_TYPES ty = RelocationEntry::type_from_data(arch, *data);
+        auto entry = std::make_unique<RelocationEntry>(pos, ty);
+        entry->relocation_ = relocation.get();
+        relocation->entries_.push_back(std::move(entry));
+      }
+    }
+    relocs.push_back(std::move(relocation));
+    stream.increment_pos(*BlockSize - 8);
+  }
+  return relocs;
+}
+
 }
 }
