@@ -2,7 +2,7 @@
 import lief
 from utils import get_sample
 
-lief.logging.set_level(lief.logging.LOGGING_LEVEL.INFO)
+lief.logging.set_level(lief.logging.LEVEL.INFO)
 
 def test_art17():
     boot = lief.ART.parse(get_sample("ART/ART_017_AArch64_boot.art"))
