@@ -7,11 +7,18 @@ import stat
 import subprocess
 import sys
 import pytest
+import shutil
 from pathlib import Path
 from textwrap import dedent
 
 from subprocess import Popen
-from utils import is_linux, glibc_version, get_sample
+from utils import (
+    is_linux, glibc_version, get_sample,
+    has_private_samples, is_server_ci, ci_runner_arch,
+    is_x86_64
+)
+
+# pyright: reportOptionalMemberAccess=false
 
 SAMPLE_DIR = pathlib.Path(os.getenv("LIEF_SAMPLES_DIR", ""))
 
@@ -260,7 +267,6 @@ def test_issue_970(tmp_path: Path):
     assert svd_0.auxiliary_symbols[0].name == "libcudart.so.12"
     assert svd_1.auxiliary_symbols[0].name == "libcudart.so.12"
 
-
 def test_issue_1121(tmp_path: Path):
     elf = lief.ELF.parse(get_sample("ELF/issue_1121.elf"))
     elf.get_symbol("main").name = "main_test"
@@ -271,6 +277,7 @@ def test_issue_1121(tmp_path: Path):
     new = lief.ELF.parse(out)
     assert new.has_symbol("main_test")
 
+
 @pytest.mark.skipif(not has_private_samples(), reason="needs private samples")
 def test_smart_insert_1(tmp_path: Path):
     """
@@ -297,7 +304,8 @@ def test_smart_insert_1(tmp_path: Path):
 
     if is_linux():
         llvm_strip = shutil.which("llvm-strip")
-        assert llvm_strip is not None
+        if llvm_strip is None:
+            pytest.skip("skipping: missing 'llvm-strip'")
         print(f"Using llvm-strip: {llvm_strip}")
         popen_args = {
             "universal_newlines": True,
@@ -310,7 +318,7 @@ def test_smart_insert_1(tmp_path: Path):
             output.as_posix()
         ]
         with Popen(args, **popen_args) as proc: # type: ignore[call-overload]
-            stdout, _ = proc.communicate(10)
+            stdout, _ = proc.communicate(timeout=10)
             print("stdout:", stdout)
             assert proc.returncode == 0
             assert len(stdout) == 0
@@ -340,7 +348,9 @@ def test_smart_insert_2(tmp_path: Path):
 
     if is_linux():
         llvm_strip = shutil.which("llvm-strip")
-        assert llvm_strip is not None
+        if llvm_strip is None:
+            pytest.skip("skipping: missing 'llvm-strip'")
+
         print(f"Using llvm-strip: {llvm_strip}")
         popen_args = {
             "universal_newlines": True,
@@ -354,7 +364,7 @@ def test_smart_insert_2(tmp_path: Path):
         ]
 
         with Popen(args, **popen_args) as proc: # type: ignore[call-overload]
-            stdout, _ = proc.communicate(10)
+            stdout, _ = proc.communicate(timeout=10)
             print("stdout:", stdout)
             assert proc.returncode == 0
             assert len(stdout) == 0
@@ -383,3 +393,92 @@ def test_issue_1175_missing_segment(tmp_path: Path):
     | 02 02 00 00 70 02 02 00 00 72 02 02 00 00 74 02  | ....p....r....t. |
     | 02 00 00 80 02 02 00 00                          | ........         |
     +---------------------------------------------------------------------+""")
+
+def test_ld_relocations(tmp_path: Path):
+    elf = lief.ELF.parse(get_sample("ELF/ld-linux-x32.so.2"))
+    elf.relocate_phdr_table()
+
+    config = lief.ELF.Builder.config_t()
+    config.force_relocate = True
+    output = tmp_path / "ld.so"
+    elf.write(output.as_posix(), config)
+    output.chmod(0o755)
+
+    new = lief.ELF.parse(output)
+    assert new.header.program_header_offset == 0x36000
+
+    if is_linux() and is_x86_64():
+        with Popen([output.as_posix(), "--version"], universal_newlines=True,
+                   stdout=subprocess.PIPE, stderr=subprocess.STDOUT) as proc:
+            stdout = proc.stdout.read()
+            proc.poll()
+            assert "version 2.41" in stdout
+
+
+def test_s390x(tmp_path: Path):
+    elf = lief.ELF.parse(get_sample("ELF/s390x-linux-gnu-libc.so"))
+
+    r = elf.get_relocation("_dl_exception_create")
+    assert r.address == 0x1c5008
+    assert int.from_bytes(elf.get_content_from_virtual_address(r.address, 8), byteorder='big') == 0x2b07e
+
+    output = tmp_path / "s390x-linux-gnu-libc.so"
+
+    elf.relocate_phdr_table()
+
+    config = lief.ELF.Builder.config_t()
+    config.force_relocate = True
+
+    elf.write(output.as_posix(), config)
+    new = lief.ELF.parse(output)
+
+    r = new.get_relocation("_dl_exception_create")
+    assert r.address == 0x1c6008
+    assert int.from_bytes(elf.get_content_from_virtual_address(r.address, 8), byteorder='big') == 0x2c07e
+
+    assert new.dynamic_entries[18].flags == [lief.ELF.DynamicEntryFlags.FLAG.STATIC_TLS]
+
+def test_patchelf(tmp_path: Path):
+    elf = lief.ELF.parse(get_sample("ELF/lief-patchelf"))
+    elf.relocate_phdr_table()
+
+    config = lief.ELF.Builder.config_t()
+    config.force_relocate = True
+    config.skip_dynamic = True
+
+    output = tmp_path / "lief-patchelf"
+
+    elf.write(output.as_posix(), config)
+
+    output.chmod(0o755)
+
+    if is_linux() and is_x86_64():
+        with Popen([output.as_posix(), "--version"], universal_newlines=True,
+                   stdout=subprocess.PIPE, stderr=subprocess.STDOUT) as proc:
+            stdout = proc.stdout.read()
+            proc.poll()
+            assert "0.17.0.0" in stdout
+
+def test_remove_segment(tmp_path: Path):
+    elf = lief.ELF.parse(get_sample("ELF/lief-patchelf"))
+
+    elf.remove(lief.ELF.Segment.TYPE.GNU_RELRO)
+    elf.remove(lief.ELF.Segment.TYPE.GNU_STACK)
+    elf.remove(lief.ELF.Segment.TYPE.NOTE)
+    elf.remove(lief.ELF.Segment.TYPE.GNU_EH_FRAME)
+
+    output = tmp_path / "lief-patchelf"
+
+    elf.write(output.as_posix())
+
+    new = lief.ELF.parse(output)
+
+    assert new.get(lief.ELF.Segment.TYPE.GNU_EH_FRAME) is None
+
+    if is_linux() and is_x86_64():
+        output.chmod(0o755)
+        with Popen([output.as_posix(), "--version"], universal_newlines=True,
+                   stdout=subprocess.PIPE, stderr=subprocess.STDOUT) as proc:
+            stdout = proc.stdout.read()
+            proc.poll()
+            assert "0.17.0.0" in stdout
